package com.wor.cordova.plugin.video;

import android.content.Intent;
import android.os.Looper;
import android.util.Log;
import com.wor.appvideo.PlayActivity;
import org.apache.cordova.CallbackContext;
import org.apache.cordova.CordovaPlugin;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.LinkedList;
import java.util.List;
import cn.kaer.mobilevideo.core.KaerController;
import cn.kaer.mobilevideo.entity.Node;
import cn.kaer.mobilevideo.service.LoginListener;

/**
 * Created by lcy on 2017/2/16.
 */

public class AppVideo extends CordovaPlugin{

    private KaerController controller = KaerController.getInstance();
    private LoginListener listener;
    private final String LOGIN = "login";
    private final String GET_NODES = "getNodes";
    private final String PLAY = "play";
    private final String LOGOUT = "logout";
    private final String GET_ALL_NODES = "getAllNodes";
    private static List rootNodes;

    @Override
    public boolean execute(String action, JSONArray args, final CallbackContext callbackContext) throws JSONException {
        if (LOGIN.equals(action)) {
            login(args, callbackContext);
        }
        if (GET_NODES.equals(action)) {
            getNodes(args, callbackContext);
        }
        if (PLAY.equals(action)) {
            play(args, callbackContext);
        }
        if (LOGOUT.equals(action)) {
            logout(args, callbackContext);
        }
        if (GET_ALL_NODES.equals(action)) {
            getAllNodes(args, callbackContext);
        }
        return true;
    }

    /**
     * 获取所有的设备信息
     * @param args
     * @param callbackContext
     * @throws JSONException
     */
    private void getAllNodes(JSONArray args, CallbackContext callbackContext) throws JSONException {
        Log.v("worlcy", "aaaa===="+args.toString());

        JSONArray data = addNodes(null);
        JSONObject result = new JSONObject();
        result.put("state", true);
        result.put("response", data);
        callbackContext.success(result);
    }

    /**
     * 获取所有的设备方法
     * @param id
     * @return
     * @throws JSONException
     */
    private JSONArray addNodes(String id) throws JSONException {

        List<Node> list;
        if (id == null) {
            if (rootNodes == null) {
                rootNodes = controller.getNodes(null);
            }
            list = rootNodes;
        } else {
            list = controller.getNodes(id);
        }

        Log.v("worlcy",  "id="+id+"==="+list.size()+"个");
        JSONArray data = new JSONArray();

        for (Node node : list) {
            JSONObject temp = new JSONObject();
            temp.put("id", node.getId());
            temp.put("nodeID", node.getNodeID());
            temp.put("name", node.getName());
            temp.put("type", node.getType());
            temp.put("parentID", node.getParentID());
            temp.put("inforID", node.getInforID());
            temp.put("state", node.getState());
            temp.put("videoType", node.getVideoType()== null? "null": node.getVideoType());
            temp.put("alert", node.getAlert());
            temp.put("mac", node.getMac());
            temp.put("chilren", addNodes(node.getId()+""));
            data.put(temp);
        }
        return data;
    }

    /**
     * 退出登录
     * @param args
     * @param callbackContext
     * @throws JSONException
     */
    private void logout(JSONArray args, CallbackContext callbackContext) throws JSONException {
        Log.v("worlcy","logout success...");
        JSONObject params = args.getJSONObject(0);
        controller.logout();
        callbackContext.success();
    }

    /**
     * 播放视频
     * @param args
     * @param callbackContext
     * @throws JSONException
     */
    private void play(JSONArray args, CallbackContext callbackContext) throws JSONException {
        JSONObject params = args.getJSONObject(0);
        Log.v("worlcy", "调用play成功."+args.toString());

        String nodeID = params.getString("nodeID");
        String inforID = params.getString("inforID");
        String videoType = params.getString("videoType").equals("null") ? null: params.getString("videoType");

        Intent intent = new Intent(this.cordova.getActivity(), PlayActivity.class);
        intent.putExtra("nodeID", nodeID);
        intent.putExtra("inforID", inforID);
        intent.putExtra("videoType", videoType);
        this.cordova.getActivity().startActivity(intent);

        callbackContext.success();
    }

    /**
     * 获取节点
     * @param args
     * @param callbackContext
     * @throws JSONException
     */
    private void getNodes(JSONArray args, CallbackContext callbackContext) throws JSONException {
        JSONObject params = args.getJSONObject(0);
        String id = params.getString("id");
        id = id==null || id == "null" || "".equals(id.trim()) ? null : id.trim();
        Log.v("worlcy", args.toString()+", id="+id);
        List<Node> list = controller.getNodes(id);
        JSONArray data = new JSONArray();
        for (Node node : list) {
            JSONObject temp = new JSONObject();
            temp.put("id", node.getId());
            temp.put("nodeID", node.getNodeID());
            temp.put("name", node.getName());
            temp.put("type", node.getType());
            temp.put("parentID", node.getParentID());
            temp.put("inforID", node.getInforID());
            temp.put("state", node.getState());
            temp.put("videoType", node.getVideoType()== null? "null": node.getVideoType());
            temp.put("alert", node.getAlert());
            temp.put("mac", node.getMac());
            data.put(temp);
        }
        JSONObject result = new JSONObject();
        result.put("state", true);
        result.put("response", data);
        Log.v("worlcy", list.size()+"="+data.length()+",finished...."+result.toString());

        callbackContext.success(result);
    }

    /**
     * 登录
     * @param args
     * @param callbackContext
     * @throws JSONException
     */
    private void login(final JSONArray args, final CallbackContext callbackContext) throws JSONException {
        Log.v("worlcy", args.toString());

        rootNodes = null;
        listener = new LoginListener(){
            JSONObject result;
            @Override
            public void onLoginStatus(int status) {
                if (!Thread.currentThread().isInterrupted()) {
                    Looper.prepare();
                    try {
                        result = new JSONObject();
                        if (status == KaerController.LOGIN_OK) {
                            Log.v("worlcy", "登录成功2");
                            result.put("state", true);
                            result.put("response", "成功");
                            callbackContext.success(result);
                        } else if (status == KaerController.LOGIN_USER_LOGGEDIN) {
                            Log.v("worlcy", "该用户已登录！");
                            result.put("state", false);
                            result.put("response", "该用户已登录");
                            callbackContext.error(result);
                        } else if (status == KaerController.LOGIN_WRONG_USER_OR_PASSWD) {
                            Log.v("worlcy", "用户名或密码错误！");
                            result.put("state", false);
                            result.put("response", "用户名或密码错误");
                            callbackContext.error(result);
                        } else if (status == KaerController.LOGIN_NO_RESPONSE) {
                            Log.v("worlcy", "超时无响应,请检查网络或联系服务提供商！");
                            result.put("state", false);
                            result.put("response", "超时无响应,请检查网络或联系服务提供商");
                            callbackContext.error(result);
                        } else if (status == KaerController.LOGIN_LOST) {
                            Log.v("worlcy", "拦截SDK发来的登录断开消息，在登录界面无需处理");
                            result.put("state", false);
                            result.put("response", "拦截SDK发来的登录断开消息，在登录界面无需处理");
                            callbackContext.error(result);
                        } else {
                            Log.v("worlcy", "未知错误！");
                            result.put("state", false);
                            result.put("response", "未知错误");
                            callbackContext.error(result);
                        }
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                    Looper.loop();
                }
            }
        };
        JSONObject params = args.getJSONObject(0);
        String ip = params.getString("ip");
        String username = params.getString("username");
        String password = params.getString("password");
        controller.registerLoginListener(listener);
        controller.login(ip, username, password);
        //callbackContext.success(new JSONObject().put("state", "aaa").put("response","ok"));

        Log.v("worlcy", "return 之前1");

//
//        Intent intent = new Intent(this.cordova.getActivity(), TestActivity.class);
//        //this.cordova.getActivity().startActivity(intent);
//        this.cordova.startActivityForResult(this, intent, 0);
//        return true;
    }


}
